AVPlayerState class

Immutable snapshot of a video player's state.

Annotations

Constructors

AVPlayerState({Duration position = Duration.zero, Duration duration = Duration.zero, Duration buffered = Duration.zero, bool isPlaying = false, bool isBuffering = false, bool isLooping = false, bool isInitialized = false, bool isInPipMode = false, bool isCompleted = false, double playbackSpeed = 1.0, double volume = 1.0, double aspectRatio = 16 / 9, String? errorDescription})
const

Properties

aspectRatio → double
final
buffered → Duration
final
duration → Duration
final
errorDescription → String?
final
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isBuffering → bool
final
isCompleted → bool
final
isInitialized → bool
final
isInPipMode → bool
final
isLooping → bool
final
isPlaying → bool
final
playbackSpeed → double
final
position → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volume → double
final

Methods

copyWith({Duration? position, Duration? duration, Duration? buffered, bool? isPlaying, bool? isBuffering, bool? isLooping, bool? isInitialized, bool? isInPipMode, bool? isCompleted, double? playbackSpeed, double? volume, double? aspectRatio, String? errorDescription}) → AVPlayerState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited