AVGestureConfig class

Configuration for AVGestures.

Constructors

AVGestureConfig({bool doubleTapToSeek = true, Duration seekDuration = const Duration(seconds: 10), bool swipeToVolume = true, bool swipeToBrightness = true, bool longPressSpeed = true, double longPressSpeedMultiplier = 2.0, bool horizontalSwipeToSeek = false})
const

Properties

doubleTapToSeek bool
Whether double-tapping the left/right side skips backward/forward.
final
hashCode int
The hash code for this object.
no setterinherited
horizontalSwipeToSeek bool
Whether horizontal swipe seeks through the video.
final
longPressSpeed bool
Whether long-pressing plays at longPressSpeedMultiplier speed.
final
longPressSpeedMultiplier double
Playback speed while long-pressing. Defaults to 2x.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seekDuration Duration
Duration to skip on double-tap.
final
swipeToBrightness bool
Whether vertical swipe on the left side adjusts brightness.
final
swipeToVolume bool
Whether vertical swipe on the right side adjusts volume.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited